/**
 * ============================================================
 *
 * This file is a part of the build-system-essentials project
 *
 * Copyright (C) 2012 CoR-Lab, Bielefeld University
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================
 */
package corlab.buildsystemessentials;

import rsb.Factory;
import rsb.Informer;
import rsb.Scope;
import corlab.buildsystemessentials.MagicNumberTransformer;

/**
 * An example that demonstrated how to send events in java.
 *
 * @author jwienke
 */
// mark-start::show-for-parsing
public class Runner {

    private static rsb.Scope scope;
    private static long magicNumber;

    private static void parseArguments() {
        scope = new Scope(System.getProperty("buildsystemessentials.scope", "/default/scope"));
        magicNumber = Long.parseLong(System.getProperty("buildsystemessentials.magicnumber", "42"));
    }

    public static void main(String[] args) throws Throwable {

        // extract values of global variables form system properties.
        parseArguments();

        // get a factory instance to create new RSB domain objects
        Factory factory = Factory.getInstance();

        // create an informer on scope "/example/informer" to send event
        // notifications. This informer is capable of sending Strings.
        Informer<Long> informer = factory.createInformer(scope);

        // activate the informer to be ready for work
        informer.activate();

        // send some data
        informer.send(new MagicNumberTransformer().transform(42));

        // as there is no explicit removal model in java, always manually
        // deactivate the informer if it is not needed anymore
        informer.deactivate();

    };

}
//mark-end::show-for-parsing
